@@ -7,7 +7,7 @@ Basking.io — Python SDK
 import json
 import logging
 import os
-from datetime import datetime, timedelta, date
+from datetime import datetime, timedelta, date, time
 from typing import Tuple, Iterator, Union, List
 
 import pandas
@@ -313,8 +313,9 @@ class Occupancy:
         """
         Returns the peak occupancy KPI by areas for a floor id between the specified time period.
         """
-        start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-        end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
+        building_id = self.basking.location.get_floor_meta_info(basking_floor_id)['data']['getFloor']['buildingId']
+        start_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, start_date)
+        end_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, end_date)
         self.log.debug(
             """Started get_floor_heatmap_kpi with
                     - basking_floor_id=%s
@@ -361,8 +362,8 @@ class Occupancy:
         end_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, end_date)
         query, variables = self.basking.graphql_query.get_location_duration_of_visits_graphql_query(
             building_id,
-            start_date.isoformat(),
-            end_date.isoformat(),
+            start_date,
+            end_date,
         )
 
         result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
@@ -406,8 +407,8 @@ class Occupancy:
         Read more about this feature here:
         https://basking.io/blog/new-features/understand-the-frequency-of-visits-to-your-office/.
          """
-        start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-        end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
+        start_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, start_date)
+        end_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, end_date)
 
         query, variables = self.basking.graphql_query.get_location_frequency_of_visits_graphql_query(
             building_id,
@@ -513,8 +514,8 @@ class Occupancy:
         :return: Data frame or array of popular days of visit.
         """
         try:
-            start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-            end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
+            start_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, start_date)
+            end_date = self.basking.utils.convert_timestamp_to_building_timezone(building_id, end_date)
 
             self.log.debug('Started get_popular_day_of_visit with'
                            ' - building_id=%s'
@@ -551,12 +552,10 @@ class Occupancy:
         """
 
         try:
-            start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-            end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
             query, variables = self.basking.graphql_query.get_organization_duration_of_visits_graphql_query(
                 organization_id=organization_id,
-                start_date=start_date,
-                end_date=end_date,
+                start_date=datetime.combine(start_date, time()),
+                end_date=datetime.combine(end_date, time()),
             )
             result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
             data = json.loads(result)
@@ -585,12 +584,10 @@ class Occupancy:
         """
 
         try:
-            start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-            end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
             query, variables = self.basking.graphql_query.get_organization_frequency_of_visits_graphql_query(
                 organization_id=organization_id,
-                start_date=start_date,
-                end_date=end_date,
+                start_date=datetime.combine(start_date, time()),
+                end_date=datetime.combine(end_date, time()),
             )
 
             result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
@@ -620,13 +617,10 @@ class Occupancy:
         """
         Returns the popular days of visit between the specified time range at organization level.
         """
-        start_date = self.basking.utils.convert_timestamp_to_building_timezone(start_date)
-        end_date = self.basking.utils.convert_timestamp_to_building_timezone(end_date)
-
         query, variables = self.basking.graphql_query.get_organization_popular_days_of_visits_graphql_query(
             organization_id=organization_id,
-            start_date=start_date,
-            end_date=end_date,
+            start_date=datetime.combine(start_date, time()),
+            end_date=datetime.combine(end_date, time()),
         )
         result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
         data = json.loads(result)
